@@ -24,7 +24,10 @@
 #ifndef ERRS_H
 #define ERRS_H
 /*----------------------------------------------------------------------------*/
-enum {
+/**
+ * @brief  My error values.
+ */
+enum e_error_values {
     ERR_OK = 0,  /**< OK */
     ERR_FILE,    /**< File error (cannot access / bad permissions) */
     ERR_FILE_RW, /**< File read / write error */
