@@ -147,12 +147,12 @@ GSList     * file_paths_to_imageinfo  (const GSList     *gsl_files1);
  * @param[out] ii_info  ImageInfo object with data to get
  * @return     File path string
  *
- * @fn  void imageinfo_set_width (ImageInfo *ii_info, uint16_t ui_val)
+ * @fn  void imageinfo_set_width (ImageInfo *ii_info, const int val)
  *
  * @brief  Set image width information
  *
  * @param[out] ii_info  ImageInfo object to set data
- * @param[in]  ui_val   Image width value
+ * @param[in]  val      Image width value
  * @return     none
  *
  * @fn  int imageinfo_get_width (const ImageInfo *ii_info)
@@ -162,12 +162,12 @@ GSList     * file_paths_to_imageinfo  (const GSList     *gsl_files1);
  * @param[out] ii_info  ImageInfo object with data to get
  * @return     Width of an image
  *
- * @fn  void imageinfo_set_height (ImageInfo *ii_info, uint16_t ui_val)
+ * @fn  void imageinfo_set_height (ImageInfo *ii_info, const int val)
  *
  * @brief  Set image height information
  *
  * @param[out] ii_info  ImageInfo object to set data
- * @param[in]  ui_val   Image height value
+ * @param[in]  val      Image height value
  * @return     none
  *
  * @fn  int imageinfo_get_height (const ImageInfo *ii_info)
@@ -177,7 +177,7 @@ GSList     * file_paths_to_imageinfo  (const GSList     *gsl_files1);
  * @param[out] ii_info  ImageInfo object with data to get
  * @return     Height of an image
  *
- * @fn  const char * imageinfo_get_wxh (ImageInfo *ii_info)
+ * @fn  const char * imageinfo_get_wxh (const ImageInfo *ii_info)
  *
  * @brief  Get string with image dimensions (width x height)
  *
@@ -185,45 +185,53 @@ GSList     * file_paths_to_imageinfo  (const GSList     *gsl_files1);
  * @return     String with image dimensions
  */
 /*----------------------------------------------------------------------------*/
-void         imageinfo_set_full_name  (ImageInfo        *ii_info,
-                                       const char       *s_name)
-             __attribute__ ((nonnull (2)));
+void imageinfo_set_full_name (ImageInfo       *ii_info,
+                              const char      *s_name)
+     __attribute__ ((nonnull (2)));
 
-const char * imageinfo_get_full_name  (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline const char * imageinfo_get_full_name (const ImageInfo *ii_info) {
+     return (const char*) ii_info->s_full_path;       
+}
 /*----------------------------------------------------------------------------*/
-void         imageinfo_set_file_name  (ImageInfo        *ii_info,
-                                       const char       *s_name)
-             __attribute__ ((nonnull (2)));
+void imageinfo_set_file_name  (ImageInfo        *ii_info,
+                               const char       *s_name)
+     __attribute__ ((nonnull (2)));
 
-const char * imageinfo_get_file_name  (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline const char * imageinfo_get_file_name (const ImageInfo *ii_info) {
+     return (const char*) ii_info->s_file_name;
+}
 /*----------------------------------------------------------------------------*/
-void         imageinfo_set_file_path  (ImageInfo        *ii_info,
-                                       const char       *s_name)
-             __attribute__ ((nonnull (2)));
+void imageinfo_set_file_path  (ImageInfo        *ii_info,
+                               const char       *s_name)
+     __attribute__ ((nonnull (2)));
 
-const char * imageinfo_get_file_path  (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline const char * imageinfo_get_file_path (const ImageInfo *ii_info) {
+     return (const char*) ii_info->s_file_path;       
+}
 /*----------------------------------------------------------------------------*/
-void         imageinfo_set_width      (ImageInfo        *ii_info,
-                                       const int         i_val);
-
-int          imageinfo_get_width      (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline void imageinfo_set_width (ImageInfo        *ii_info,
+                                        const int         val) {
+    ii_info->i_width = val;
+}
+static inline int imageinfo_get_width  (const ImageInfo  *ii_info) {
+    return ii_info->i_width;
+}
 /*----------------------------------------------------------------------------*/
-void         imageinfo_set_height     (ImageInfo        *ii_info,
-                                       const int         i_val);
-
-int          imageinfo_get_height     (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline void imageinfo_set_height (ImageInfo        *ii_info,
+                                         const int         val) {
+    ii_info->i_height = val;
+}
+static inline int  imageinfo_get_height (const ImageInfo  *ii_info) {
+    return ii_info->i_height;
+}
 /*----------------------------------------------------------------------------*/
 void         imageinfo_set_wxh        (ImageInfo        *ii_info,
                                        const int         i_w,
                                        const int         i_h);
 
-const char * imageinfo_get_wxh        (const ImageInfo  *ii_info)
-             __attribute__ ((pure));
+static inline const char * imageinfo_get_wxh (const ImageInfo *ii_info) {
+    return (const char*) ii_info->s_width_height;
+}
 /*----------------------------------------------------------------------------*/
 #endif
 
