@@ -88,27 +88,26 @@ void      urldata_get_to_file   (const char *s_url,
  * @param[in] s_query     Search query
  * @param[in] s_api_key   Pexels API key
  * @param[in] i_page      Results page number
- * @param[in] i_per_page  Result images per page
  * @return    UrlData item with downloaded data or error info
  */
 UrlData * urldata_search_pexels (const char *s_query,
+                                 const char *s_search_opts,
                                  const char *s_api_key,
-                                 const int   i_page,
-                                 const int   i_per_page);
+                                 const int   i_page);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Search Pixbay for images.
  *
- * @param[in] s_query     Search query
- * @param[in] s_api_key   Pixbay API key
- * @param[in] i_page      Results page number
- * @param[in] i_per_page  Result images per page
+ * @param[in] s_query        Search query
+ * @param[in] s_search_opts  Search options
+ * @param[in] s_api_key      Pixbay API key
+ * @param[in] i_page         Results page number
  * @return    UrlData item with downloaded data or error info
  */
 UrlData * urldata_search_pixbay (const char *s_query,
+                                 const char *s_search_opts,
                                  const char *s_api_key,
-                                 const int   i_page,
-                                 const int   i_per_page);
+                                 const int   i_page);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Search Wallhaven for images.
@@ -116,13 +115,12 @@ UrlData * urldata_search_pixbay (const char *s_query,
  * @param[in] s_query     Search query
  * @param[in] s_api_key   Wallhaven API key
  * @param[in] i_page      Results page number
- * @param[in] i_per_page  Result images per page
  * @return    UrlData item with downloaded data or error info
  */
 UrlData * urldata_search_wallhaven (const char *s_query,
+                                    const char *s_search_opts,
                                     const char *s_api_key,
-                                    const int   i_page,
-                                    const int   i_per_page);
+                                    const int   i_page);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if UrlData's data buffer is not empty.
