@@ -35,9 +35,17 @@
 #include "errs.h"
 #include "searchitem.h"
 #include "urldata.h"
+#include "setts.h"
+#include "setting.h"
 #include "webwidget_c.h"
 #include "webpexels.h"
 /*----------------------------------------------------------------------------*/
+/**
+ * @def   SERV_NAME
+ * @brief Service name
+ */
+#define SERV_NAME "Pexels" 
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Extract base image name from image url.
  *
@@ -150,7 +158,7 @@ pexels_json_obj_to_searchitem (json_object *j_obj)
 
     SearchItem *si_item = searchitem_new ();
 
-    searchitem_set_service_name (si_item, "Pexels");
+    searchitem_set_service_name (si_item, SERV_NAME);
 
     if (json_object_object_get_ex (j_obj, "id", &j_val) &&
         json_object_get_type (j_val) == json_type_int) {
@@ -225,13 +233,13 @@ pexels_json_obj_to_searchitem (json_object *j_obj)
  *
  * @param[in]  s_buff     String with json data
  * @param[out] ww_widget  Webwidget to set data
- * @param[out] si_items   List of SearchItem items
+ * @param[out] cq_query   CacheQuery item to insert SearchItem items
  * @return     none
  */
 static void
-pexels_json_to_webwidget (const char  *s_buff,
-                          WebWidget   *ww_widget,
-                          SearchItem **si_items)
+pexels_json_to_webwidget (const char *s_buff,
+                          WebWidget  *ww_widget,
+                          CacheQuery *cq_query)
 {
     json_object *j_obj;            /* Json with search data */
     json_object *j_val;            /* Some value */
@@ -267,18 +275,15 @@ pexels_json_to_webwidget (const char  *s_buff,
 
             ui_cnt = json_object_array_length (j_arr);
 
-            if (ui_cnt > (size_t) ww_widget->i_per_page)
-                ui_cnt = (size_t) ww_widget->i_per_page;
-
             for (i = 0; i < ui_cnt; ++i) {
                 if ((j_val = json_object_array_get_idx (j_arr, i)) != NULL) {
                     si_item = pexels_json_obj_to_searchitem (j_val);
                     add_searchitem_to_img_view (ww_widget->gw_img_view,
                                                 si_item,
-                                                ww_widget->s_thumb_dir,
                                                 ww_widget->s_wallp_dir,
-                                                "pexels_");
-                    *si_items++ = si_item;
+                                                SERV_NAME,
+                                                ww_widget->i_thumb_quality);
+                    cachequery_append_item (cq_query, si_item);
                 }
             }
         }
@@ -298,32 +303,31 @@ pexels_search (WebWidget         *ww_widget,
     char       *s_query      = NULL; /* For search query */
     int         i_err        = 0;    /* Error output */
 
-    if (str_is_empty_msg (fs_data->s_str1, "Pexels API key is not set"))
+    if (str_is_empty_msg (fs_data->s_str1, SERV_NAME " API key is not set"))
         return;
     /* Check if there is a cached info about this search query */
-    if (check_for_cached_query (ww_widget, "Pexels", "pexels_"))
+    if (check_for_cached_query (ww_widget, SERV_NAME))
         return;
 
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
 
     ud_data = urldata_search_pexels (s_query,
+                                     ww_widget->s_search_opts,
                                      fs_data->s_str1,
-                                     ww_widget->i_page,
-                                     ww_widget->i_per_page);
+                                     ww_widget->i_page);
     if (ud_data->errbuf != NULL) {
         message_dialog_error (NULL, ud_data->errbuf);
     }
     else if (urldata_full (ud_data)) {
-        cq_query = cachequery_new ("Pexels",
+        cq_query = cachequery_new (SERV_NAME,
                                    ww_widget->s_query,
-                                   ww_widget->i_page,
-                                   ww_widget->i_per_page);
+                                   ww_widget->s_search_opts,
+                                   ww_widget->i_page);
 
         gtk_list_store_clear (GTK_LIST_STORE (gtk_icon_view_get_model (
                     GTK_ICON_VIEW (ww_widget->gw_img_view))));
 
-        pexels_json_to_webwidget (ud_data->buffer, ww_widget,
-                                  cq_query->si_items);
+        pexels_json_to_webwidget (ud_data->buffer, ww_widget, cq_query);
         cq_query->i_found_cnt = ww_widget->i_found_cnt;
 
         i_err = cachequery_save (cq_query);
@@ -350,7 +354,7 @@ pexels_settings_dialog (FourStrings *fs_data)
 
     GtkDialogFlags flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
 
-    gw_dialog = gtk_dialog_new_with_buttons ("Pexels configuration",
+    gw_dialog = gtk_dialog_new_with_buttons (SERV_NAME " configuration",
                                              NULL,
                                              flags,
                                              "_OK",
@@ -368,7 +372,7 @@ pexels_settings_dialog (FourStrings *fs_data)
 
     /* Packing dialog widgets */
     gtk_box_pack_start (GTK_BOX (gw_content_box),
-                        gtk_label_new ("Pexels API key:"),
+                        gtk_label_new (SERV_NAME " API key:"),
                         FALSE, FALSE, 4);
     gtk_box_pack_start (GTK_BOX (gw_content_box),
                         gw_api_entry,
@@ -399,4 +403,125 @@ pexels_settings_dialog (FourStrings *fs_data)
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get search options from Setting item to widgets.
+ *
+ * @param[out] gw_per_page  Widget with images per page
+ * @param[in]  st_setts  Setting item with list of options
+ * @return     none
+ */
+static void
+set_search_opts (GtkWidget *gw_per_page,
+                 Setting   *st_setts)
+{
+    Setting *st_set  = NULL;
+    Setting *st_item = NULL;
+
+    st_set = setting_get_child (settings_find (st_setts, SERV_NAME "_opts"));
+
+    if (st_set == NULL) {
+        return;
+    }
+#ifdef DEBUG
+    settings_print (st_set);
+#endif
+    if ((st_item = settings_find (st_set, "per_page")) != NULL) {
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (gw_per_page),
+                                   (double) setting_get_int (st_item));
+#ifdef DEBUG
+        printf ("set : %s %ld\n", "per_page", setting_get_int (st_item));
+#endif
+    }
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get search options from widgets to Setting item.
+ *
+ * @param[in] gw_per_page  Widget with images per page
+ * @return    Setting items with search options
+ */
+static Setting *
+get_search_opts (GtkWidget *gw_per_page)
+{
+    Setting    *st_sett = NULL;
+    int         i_val   = 0;
+
+    i_val = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gw_per_page));
+    st_sett = setting_new_int ("per_page", i_val);
+
+    return st_sett;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Options for image search dialog.
+ */
+char *
+pexels_search_opts_dialog (WebWidget *ww_widget)
+{
+    GtkAdjustment *ga_adjust1;         /* Adjustment for per page spinbutton */
+    GtkWidget     *gw_per_page;        /* Spin button for per page */
+    GtkWidget     *gw_dialog;          /* Pexels settings dialog */
+    GtkWidget     *gw_content_box;     /* Dialog's box */
+    GtkWidget     *gw_hbox;            /* Horizontal box for widgets */
+    Setting       *st_settings = NULL; /* Settings */
+    char          *s_res       = NULL; /* Result string */
+    int            i_err       = 0;    /* Error output */
+    int            i_res       = 0;    /* Dialog result */
+
+    GtkDialogFlags flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
+
+    ga_adjust1 = gtk_adjustment_new (12.0, 1.0, 80.0, 1.0, 2.0, 0.0);
+
+    gw_dialog = gtk_dialog_new_with_buttons (SERV_NAME " search options",
+                                             NULL,
+                                             flags,
+                                             "_OK",
+                                             GTK_RESPONSE_ACCEPT,
+                                             "_Cancel",
+                                             GTK_RESPONSE_REJECT,
+                                             NULL);
+
+    gw_content_box = gtk_dialog_get_content_area (GTK_DIALOG (gw_dialog));
+    gtk_container_set_border_width (GTK_CONTAINER (gw_content_box), 8);
+    gw_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
+
+    /* Images per page */
+    gw_per_page = gtk_spin_button_new (ga_adjust1, 1.0, 0);
+    gtk_box_pack_start (GTK_BOX (gw_hbox),
+                        gtk_label_new ("Images per page:"),
+                        FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (gw_hbox),
+                        gw_per_page,
+                        FALSE, FALSE, 4);
+
+    gtk_box_pack_start (GTK_BOX (gw_content_box), gw_hbox, FALSE, FALSE, 4);
+
+    st_settings = setts_read (ww_widget->s_cfg_file, &i_err);
+    set_search_opts (gw_per_page, setting_get_child (st_settings));
+    settings_free_all (st_settings);
+
+    gtk_widget_show_all (gw_content_box);
+
+    i_res = gtk_dialog_run (GTK_DIALOG (gw_dialog));
+
+    if (i_res == GTK_RESPONSE_ACCEPT) {
+        st_settings = setting_new_setting (SERV_NAME "_opts");
+
+        setting_add_child (st_settings, get_search_opts (gw_per_page));
+#ifdef DEBUG
+        settings_print (st_settings);
+#endif
+        setts_check_update_file (ww_widget->s_cfg_file, st_settings);
+        s_res = search_opts_to_str (setting_get_child (st_settings));
+        settings_free_all (st_settings);
+    }
+    else {
+        s_res = NULL;
+    }
+    gtk_widget_destroy (gw_dialog);
+
+    return s_res;
+
+}
+/*----------------------------------------------------------------------------*/
 
