@@ -320,12 +320,11 @@ combo_set_active_strings (GtkWidget         *gw_combo,
 static void
 update_labels (WebWidget *ww_widget)
 {
-    const char *s_format_count = "Search query: %s,  Found %d images";
+    const char *s_format_count = "Found %d images";
     char       *s_markup       = NULL;
     char        s_entry[128];
 
     s_markup = g_markup_printf_escaped (s_format_count,
-                                        ww_widget->s_query,
                                         ww_widget->i_found_cnt);
     gtk_label_set_markup (GTK_LABEL (ww_widget->gw_count_label), s_markup);
     g_free (s_markup);
@@ -465,6 +464,50 @@ event_search_pressed (WebWidget *ww_widget)
     search_web (ww_widget);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Search options button pressed.
+ *
+ * @param[in,out] ww_widget  WebWidget with widgets and search data
+ * @return        none
+ */
+static void
+event_search_opts_pressed (WebWidget *ww_widget)
+{
+    char *s_search_opts = NULL; /* Search options string */
+    int   i_id          = 0;    /* Service id */
+
+    i_id    = ww_widget->i_active_service;
+
+    switch (i_id) {
+        case WEB_WIDGET_PEXELS:
+            s_search_opts = pexels_search_opts_dialog (ww_widget);
+            break;
+        case WEB_WIDGET_PIXBAY:
+            s_search_opts = pixbay_search_opts_dialog (ww_widget);
+            break;
+        case WEB_WIDGET_WALLHAVEN:
+            s_search_opts = wallhaven_search_opts_dialog (ww_widget);
+            break;
+#ifdef HAVE_FLICKCURL
+        case WEB_WIDGET_FLICKR:
+            //flickr_search_opts_dialog (ww_widget);
+            break;
+#endif
+        default:
+            break;
+    }
+    if (s_search_opts != NULL &&
+        strcmp (s_search_opts, ww_widget->s_search_opts) != 0) {
+
+        free (ww_widget->s_search_opts);
+        ww_widget->s_search_opts = strdup (s_search_opts);
+    }
+#ifdef DEBUG
+            printf ("now opts : %s\n", ww_widget->s_search_opts);
+#endif
+    free (s_search_opts);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Next page button pressed.
  *
@@ -727,6 +770,61 @@ event_add_selected_pressed (WebWidget *ww_widget)
     }
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Refresh string with search options for active seach service.
+ *
+ * @param[in,out] ww_widget  WebWidget item
+ * @return        none
+ */
+static void
+refresh_service_opts (WebWidget *ww_widget)
+{
+    Setting *st_settings   = NULL;
+    Setting *st_item       = NULL;
+    char    *s_name        = NULL;
+    char    *s_search_opts = NULL;
+    int      i_err         = 0;
+
+    s_name = combo_get_active_str (ww_widget->gw_combo, WW_COMBO_NAME);
+    str_append (&s_name, "_opts");
+#ifdef DEBUG
+    printf ("%s\n", s_name);
+#endif
+
+    st_settings = setts_read (ww_widget->s_cfg_file, &i_err);
+    st_item     = setting_get_child (st_settings);
+    st_item     = setting_get_child (settings_find (st_item, s_name));
+
+    if (st_item != NULL) {
+        switch (ww_widget->i_active_service) {
+            case WEB_WIDGET_PEXELS:
+                s_search_opts = search_opts_to_str (st_item);
+                break;
+            case WEB_WIDGET_PIXBAY:
+                s_search_opts = search_opts_to_str (st_item);
+                break;
+            case WEB_WIDGET_WALLHAVEN:
+                s_search_opts = search_opts_to_str (st_item);
+                break;
+            default:
+                break;
+        }
+    }
+    settings_free_all (st_settings);
+    free (s_name);
+
+    if (s_search_opts != NULL &&
+        strcmp (s_search_opts, ww_widget->s_search_opts) != 0) {
+
+        free (ww_widget->s_search_opts);
+        ww_widget->s_search_opts = strdup (s_search_opts);
+    }
+#ifdef DEBUG
+    printf ("now opts : %s\n", ww_widget->s_search_opts);
+#endif
+    free (s_search_opts);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Changed cobo box with image search service, sets active service
  *         i_active_service value in WebWidget.
@@ -736,8 +834,8 @@ event_add_selected_pressed (WebWidget *ww_widget)
  * @return     none
  */
 static void
-event_combo_changed (GtkComboBox *gw_combo,
-                     WebWidget   *ww_widget)
+event_service_combo_changed (GtkComboBox *gw_combo,
+                             WebWidget   *ww_widget)
 {
     GtkTreeModel *model;
     GtkTreeIter   iter;
@@ -747,6 +845,9 @@ event_combo_changed (GtkComboBox *gw_combo,
         model = gtk_combo_box_get_model (gw_combo);
         gtk_tree_model_get (model, &iter,
                 WW_COMBO_ID, &ww_widget->i_active_service, -1);
+
+        refresh_service_opts (ww_widget);
+
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -788,7 +889,7 @@ webwidget_combobox_create (Setting *st_settings)
                                      GDK_TYPE_PIXBUF);
     /* Get Pexels API string */
     st_s1 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_PEXELS_API));
+                                get_setting_name (SETT_PEXELS_API));
 
     s_pexels_api = st_s1 == NULL ? "" : setting_get_string (st_s1);
 
@@ -808,7 +909,7 @@ webwidget_combobox_create (Setting *st_settings)
 
     /* Get Pixbay API string */
     st_s1 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_PIXBAY_API));
+                                get_setting_name (SETT_PIXBAY_API));
 
     s_pixbay_api = st_s1 == NULL ? "" : setting_get_string (st_s1);
 
@@ -827,7 +928,7 @@ webwidget_combobox_create (Setting *st_settings)
     g_object_unref (gp_logo);
     /* Get Wallhaven API string */
     st_s1 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_WALLHAVEN_API));
+                                get_setting_name (SETT_WALLHAVEN_API));
 
     s_wallha_api = st_s1 == NULL ? "" : setting_get_string (st_s1);
 
@@ -847,16 +948,16 @@ webwidget_combobox_create (Setting *st_settings)
 #ifdef HAVE_FLICKCURL
     /* Get Flickr API key string */
     st_s1 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_FLICKR_CLKEY));
+                                get_setting_name (SETT_FLICKR_CLKEY));
     /* Get Flickr API secret string */
     st_s2 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_FLICKR_CLSEC));
+                                get_setting_name (SETT_FLICKR_CLSEC));
     /* Get Flickr API access token */
     st_s3 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_FLICKR_ACTOK));
+                                get_setting_name (SETT_FLICKR_ACTOK));
     /* Get Flickr API access token */
     st_s4 = setting_find_child (st_settings,
-                                get_setting_name (SETTING_FLICKR_ACSEC));
+                                get_setting_name (SETT_FLICKR_ACSEC));
 
     s_flickr_key  = st_s1 == NULL ? "" : setting_get_string (st_s1);
     s_flickr_sec  = st_s2 == NULL ? "" : setting_get_string (st_s2);
@@ -1117,12 +1218,25 @@ void
 webwidget_free (WebWidget *ww_widget)
 {
     free (ww_widget->s_query);
+    free (ww_widget->s_search_opts);
     free (ww_widget->s_cfg_file);
-    free (ww_widget->s_thumb_dir);
     free (ww_widget->s_wallp_dir);
     free (ww_widget);
 }
 /*----------------------------------------------------------------------------*/
+void
+webwidget_init (WebWidget *ww_widget)
+{
+    ww_widget->s_query          = NULL;
+    ww_widget->s_search_opts    = NULL;
+    ww_widget->s_cfg_file       = NULL;
+    ww_widget->s_wallp_dir      = NULL;
+    ww_widget->i_page           = 0;
+    ww_widget->i_found_cnt      = 0;
+    ww_widget->i_active_service = 0;
+    ww_widget->i_thumb_quality  = 0;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Create WebWidget item with widgets and data for wallpaper search.
  */
@@ -1137,6 +1251,7 @@ webwidget_create (Setting    *st_settings,
     GtkWidget *gw_sett_button;
     GtkWidget *gw_search_entry;
     GtkWidget *gw_search_button;
+    GtkWidget *gw_search_opts_btn;
     GtkWidget *gw_nav_box;
     GtkWidget *gw_nav_prev;
     GtkWidget *gw_nav_next;
@@ -1145,10 +1260,13 @@ webwidget_create (Setting    *st_settings,
     GtkWidget *gw_add_sltd_box;
     GtkWidget *gw_add_sltd_button;
     GtkWidget *gw_selected_combo;
+    Setting *st_sett = NULL;
 
     if ((ww_widget = malloc (sizeof (WebWidget))) == NULL)
         err (EXIT_FAILURE, NULL);
 
+    webwidget_init (ww_widget);
+
     cachequery_delete_older_than ("Pexels",    1);
     cachequery_delete_older_than ("Pixbay",    1);
     cachequery_delete_older_than ("Wallhaven", 1);
@@ -1156,34 +1274,39 @@ webwidget_create (Setting    *st_settings,
     cachequery_delete_older_than ("Flickr",    1);
 #endif
 
-    ww_widget->s_cfg_file  = strdup (s_cfg_file);
-    ww_widget->s_thumb_dir = cfgfile_get_app_thumbnails_path ();
-    ww_widget->s_wallp_dir = cfgfile_get_app_wallpapers_path ();
-    dir_create_with_subdirs (ww_widget->s_thumb_dir);
+    if ((st_sett = setting_find_child (st_settings,
+                   get_setting_name (SETT_THUMB_QUALITY))) != NULL) {
+        ww_widget->i_thumb_quality = (int) setting_get_int (st_sett);
+    }
 
+    ww_widget->s_cfg_file   = strdup (s_cfg_file);
+    ww_widget->s_wallp_dir  = cfgfile_get_app_wallpapers_path ();
     ww_widget->gw_ii_widget = webwidget_imageinfo_create (ww_widget);
 
     gw_web_combo = webwidget_combobox_create (st_settings);
     gw_img_view  = webwidget_imgview_create ();
 
     g_signal_connect (gw_web_combo, "changed",
-            G_CALLBACK (event_combo_changed), ww_widget);
+            G_CALLBACK (event_service_combo_changed), ww_widget);
     g_signal_connect (gw_img_view, "item-activated",
             G_CALLBACK (event_imgview_activated), ww_widget);
 
-    gw_count_label = gtk_label_new ("Search query:   Found 0 results");
+    gw_count_label = gtk_label_new ("Found 0 images");
 
     /* Search box */
-    gw_search_box    = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
-    gw_sett_button   = gtk_button_new_with_label ("Settings");
-    gw_search_entry  = gtk_search_entry_new ();
-    gw_search_button = gtk_button_new_with_label ("Search");
-    g_signal_connect_swapped (gw_sett_button,   "clicked",
+    gw_search_box      = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
+    gw_search_entry    = gtk_search_entry_new ();
+    gw_sett_button     = gtk_button_new_with_label ("Settings");
+    gw_search_button   = gtk_button_new_with_label ("Search");
+    gw_search_opts_btn = gtk_button_new_with_label ("Search opts");
+    g_signal_connect_swapped (gw_sett_button, "clicked",
             G_CALLBACK (event_settings_pressed), ww_widget);
-    g_signal_connect_swapped (gw_search_entry,  "activate",
-            G_CALLBACK (event_search_pressed),   ww_widget);
+    g_signal_connect_swapped (gw_search_entry, "activate",
+            G_CALLBACK (event_search_pressed), ww_widget);
     g_signal_connect_swapped (gw_search_button, "clicked",
-            G_CALLBACK (event_search_pressed),   ww_widget);
+            G_CALLBACK (event_search_pressed), ww_widget);
+    g_signal_connect_swapped (gw_search_opts_btn, "clicked",
+            G_CALLBACK (event_search_opts_pressed), ww_widget);
 
     gtk_box_pack_start (GTK_BOX (gw_search_box),
                         gw_web_combo,
@@ -1197,6 +1320,9 @@ webwidget_create (Setting    *st_settings,
     gtk_box_pack_start (GTK_BOX (gw_search_box),
                         gw_search_button,
                         FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (gw_search_box),
+                        gw_search_opts_btn,
+                        FALSE, FALSE, 4);
 
     /* Navigation box */
     gw_nav_box = gtk_grid_new ();
@@ -1215,17 +1341,7 @@ webwidget_create (Setting    *st_settings,
                      1,0,1,1);
     gtk_grid_attach (GTK_GRID (gw_nav_box), gw_nav_next,
                      2,0,1,1);
-    /*
-    gtk_box_pack_start (GTK_BOX (gw_nav_box),
-                        gw_nav_prev,
-                        FALSE, FALSE, 4);
-    gtk_box_pack_start (GTK_BOX (gw_nav_box),
-                        gw_nav_entry,
-                        FALSE, FALSE, 4);
-    gtk_box_pack_start (GTK_BOX (gw_nav_box),
-                        gw_nav_next,
-                        FALSE, FALSE, 4);
-    */
+
     g_signal_connect_swapped (gw_nav_prev, "clicked",
             G_CALLBACK (event_prev_pressed), ww_widget);
     g_signal_connect_swapped (gw_nav_next, "clicked",
@@ -1257,11 +1373,10 @@ webwidget_create (Setting    *st_settings,
     ww_widget->gw_selected_combo = gw_selected_combo;
     ww_widget->gw_selected_box   = gw_add_sltd_box;
     ww_widget->gw_count_label    = gw_count_label;
-    ww_widget->s_query           = NULL;
-    ww_widget->i_page            = 0;
-    ww_widget->i_per_page        = IMGS_ON_PAGE;
-    ww_widget->i_found_cnt       = 0;
     ww_widget->i_active_service  = WEB_WIDGET_PEXELS;
+    ww_widget->s_search_opts     = strdup ("");
+
+    refresh_service_opts (ww_widget);
 
     return ww_widget;
 }
@@ -1277,7 +1392,7 @@ save_selected_wallpapers (GtkWidget *gw_dialog,
     GList *gl_res   = NULL; /* Result list od downloaded wallpapers */
 
     gl_items = sel_combo_get_list (ww_widget->gw_selected_combo);
-    gl_res = download_progress_window (GTK_WINDOW (gw_dialog), gl_items);
+    gl_res   = download_progress_window (GTK_WINDOW (gw_dialog), gl_items);
     g_list_free_full (gl_items, (GDestroyNotify) searchitem_free);
 
     return gl_res;
